@@ -1,6 +1,6 @@
 import re
 
-from smsc.exceptions import AreaCodeSMSCError, LocalNumberSMSCError, PhoneNumberLongSMSCError
+from smsc.exceptions import AreaCodeSMSCError, LocalNumberSMSCError, PhoneNumberLongSMSCError, PriorityOutOfRangeError
 
 
 def validate_phone_number(area_code, local_number):
@@ -12,6 +12,11 @@ def validate_phone_number(area_code, local_number):
         raise PhoneNumberLongSMSCError(area_code + local_number, 'The number should be 10 digits')
 
 
+def validate_phone_numbers(phone_numbers):
+    for phone_number in phone_numbers:
+        validate_phone_number(*phone_number)
+
+
 def validate_area_code(area_code):
     """
     :param area_code: <str>
@@ -34,3 +39,13 @@ def validate_length_phone_number(phone_number):
     :return: True if is valid, False otherwise
     """
     return bool(re.match(r'^\d{10}$', phone_number))
+
+
+def validate_priority(priority):
+    """
+    :param priority: <int>
+    Raise an exeption if the priority is out of range
+    :return: None
+    """
+    if not 1<=priority<=7:
+        raise PriorityOutOfRangeError(priority, 'The priority must be between 1 and 7')
